/*
Copyright (C) 2004 Dan Leinir Turthra Jensen <admin@leinir.dk>

based on the Plastik configuration dialog:
Copyright (C) 2003 Sandro Giessl <ceebx@users.sourceforge.net>

based on the Keramik configuration dialog:
Copyright (c) 2003 Maksim Orlovich <maksim.orlovich@kdemail.net>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.

*/

#include <qcheckbox.h>
#include <qwhatsthis.h>
#include <qlayout.h>
#include <qsettings.h>
#include <kglobal.h>
#include <klocale.h>

#include "reinhardtconf.h"

extern "C"
{
	QWidget* allocate_kstyle_config(QWidget* parent)
	{
		KGlobal::locale()->insertCatalogue("kstyle_reinhardt_config");
		return new ReinhardtStyleConfig(parent);
	}
}

ReinhardtStyleConfig::ReinhardtStyleConfig(QWidget* parent): QWidget(parent)
{
	//Should have no margins here, the dialog provides them
	QVBoxLayout* layout = new QVBoxLayout(this, 0, 0);
	KGlobal::locale()->insertCatalogue("kstyle_reinhardt_config");

	useTextShadows = new QCheckBox(i18n("Use text shadows"), this);
	QWhatsThis::add(useTextShadows, i18n("Enabling this option will cause Reinhardt "
					     "to draw shadows on the text used for push-buttons"));

	useDropShadows = new QCheckBox(i18n("Use drop-shadows"), this);
	QWhatsThis::add(useDropShadows, i18n("Enabling this option will cause Reinhardt "
					     "to draw fake drop-shadows on many controls"));

	useHighlightedButtons = new QCheckBox(i18n("Highlight buttons on mouse-over"), this);
	QWhatsThis::add(useHighlightedButtons, i18n("Enabling this option will cause Reinhardt "
						    "to highlight buttons and drop-down lists when "
						    "the mouse hovers over them"));

	useOldTabs = new QCheckBox(i18n("Use old-style tabs"), this);
	QWhatsThis::add(useOldTabs, i18n("Enabling this option will cause Reinhardt "
					 "to draw tabs in the old style, which means "
					 "background tabs will be a darker colour"));

	useOldCombo = new QCheckBox(i18n("Use old-style combo boxes"), this);
	QWhatsThis::add(useOldCombo, i18n("Enabling this option will cause Reinhardt "
					  "to draw combo boxes in the old style, which "
					  "means the background colour in both drop-down "
					  "lists and input combo boxes will resemble input boxes."));

	useOldTreeview = new QCheckBox(i18n("Use old-style tree views"), this);
	QWhatsThis::add(useOldCombo, i18n("Enabling this option will cause Reinhardt "
					  "to draw tree views in the old style using "
					  "lines and plus/minus."));
	
	layout->add(useTextShadows);
	layout->add(useDropShadows);
	layout->add(useHighlightedButtons);
	layout->add(useOldTabs);
	layout->add(useOldCombo);
	layout->add(useOldTreeview);
	layout->addStretch(1);

	QSettings s;
	origUseTextShadows = s.readBoolEntry("/reinhardtstyle/Settings/useTextShadows", true);
	useTextShadows->setChecked(origUseTextShadows);
	connect(useTextShadows, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	
	origUseDropShadows = s.readBoolEntry("/reinhardtstyle/Settings/useDropShadows", true);
	useDropShadows->setChecked(origUseDropShadows);
	connect(useDropShadows, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	
	origUseHighlightedButtons = s.readBoolEntry("/reinhardtstyle/Settings/useHighlightedButtons", true);
	useHighlightedButtons->setChecked(origUseHighlightedButtons);
	connect(useHighlightedButtons, SIGNAL( tobbled(bool) ), SLOT( updateChanged() ) );
	
	origUseOldTabs = s.readBoolEntry("/reinhardtstyle/Settings/useOldTabs", false);
	useOldTabs->setChecked(origUseOldTabs);
	connect(useOldTabs, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	
	origUseOldCombo = s.readBoolEntry("/reinhardtstyle/Settings/useOldCombo", false);
	useOldCombo->setChecked(origUseOldCombo);
	connect(useOldCombo, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	
	origUseOldTreeview = s.readBoolEntry("/reinhardtstyle/Settings/useOldTreeview", false);
	useOldTreeview->setChecked(origUseOldTreeview);
	connect(useOldTreeview, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
}

ReinhardtStyleConfig::~ReinhardtStyleConfig()
{
}


void ReinhardtStyleConfig::save()
{
	QSettings s;
	s.writeEntry("/reinhardtstyle/Settings/useTextShadows", useTextShadows->isChecked());
	s.writeEntry("/reinhardtstyle/Settings/useDropShadows", useDropShadows->isChecked());
	s.writeEntry("/reinhardtstyle/Settings/useHighlightedButtons", useHighlightedButtons->isChecked());
	s.writeEntry("/reinhardtstyle/Settings/useOldTabs", useOldTabs->isChecked());
	s.writeEntry("/reinhardtstyle/Settings/useOldCombo", useOldCombo->isChecked());
	s.writeEntry("/reinhardtstyle/Settings/useOldTreeview", useOldTreeview->isChecked());
}

void ReinhardtStyleConfig::defaults()
{
	useTextShadows->setChecked(true);
	useDropShadows->setChecked(true);
	useHighlightedButtons->setChecked(true);
	useOldTabs->setChecked(false);
	useOldCombo->setChecked(false);
	useOldTreeview->setChecked(false);
	//updateChanged would be done by setChecked already
}

void ReinhardtStyleConfig::updateChanged()
{
	if ( (useTextShadows->isChecked() == origUseTextShadows) &&
	     (useDropShadows->isChecked() == origUseDropShadows) &&
	     (useHighlightedButtons->isChecked() == origUseHighlightedButtons) &&
	     (useOldTabs->isChecked() == origUseOldTabs) &&
	     (useOldCombo->isChecked() == origUseOldCombo) &&
	     (useOldTreeview->isChecked() == origUseOldTreeview)
	     ) {
		emit changed(false);
	} else {
		emit changed(true);
	}
}

#include "reinhardtconf.moc"
